# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from _qwak_proto.qwak.execution.v1 import batch_pb2 as qwak_dot_execution_dot_v1_dot_batch__pb2
from _qwak_proto.qwak.execution.v1 import deletion_pb2 as qwak_dot_execution_dot_v1_dot_deletion__pb2
from _qwak_proto.qwak.execution.v1 import execution_pb2 as qwak_dot_execution_dot_v1_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/execution/v1/execution_service.proto\x12\x1fqwak.feature.store.execution.v1\x1a qwak/execution/v1/backfill.proto\x1a\x1dqwak/execution/v1/batch.proto\x1a qwak/execution/v1/deletion.proto\x1a!qwak/execution/v1/execution.proto\"^\n\x16TriggerBackfillRequest\x12\x44\n\rbackfill_spec\x18\x01 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\"/\n\x17TriggerBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"1\n\x19GetExecutionStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"h\n\x1aGetExecutionStatusResponse\x12J\n\x10\x65xecution_status\x18\x01 \x01(\x0e\x32\x30.qwak.feature.store.execution.v1.ExecutionStatus\"0\n\x18GetExecutionEntryRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"e\n\x19GetExecutionEntryResponse\x12H\n\x0f\x65xecution_entry\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"i\n\x1dTriggerBatchFeaturesetRequest\x12H\n\x0f\x62\x61tch_ingestion\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.BatchIngestion\"6\n\x1eTriggerBatchFeaturesetResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\":\n!GetRunningExecutionEntriesRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"p\n\"GetRunningExecutionEntriesResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"9\n TriggerFeaturesetDeletionRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"9\n!TriggerFeaturesetDeletionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"<\n#InitPaginationByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"Y\n$InitPaginationByFeaturesetIdResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x1b\n\x13max_execution_index\x18\x02 \x01(\x03\"\x81\x01\n#ListExecutionsByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x1b\n\x13max_execution_index\x18\x04 \x01(\x03\"r\n$ListExecutionsByFeaturesetIdResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry2\x8c\n\n\x1c\x46\x65\x61tureStoreExecutionService\x12\x89\x01\n\x14TriggerBatchBackfill\x12\x37.qwak.feature.store.execution.v1.TriggerBackfillRequest\x1a\x38.qwak.feature.store.execution.v1.TriggerBackfillResponse\x12\x99\x01\n\x16TriggerBatchFeatureset\x12>.qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest\x1a?.qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse\x12\xa2\x01\n\x19TriggerFeaturesetDeletion\x12\x41.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest\x1a\x42.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse\x12\x8d\x01\n\x12GetExecutionStatus\x12:.qwak.feature.store.execution.v1.GetExecutionStatusRequest\x1a;.qwak.feature.store.execution.v1.GetExecutionStatusResponse\x12\x8a\x01\n\x11GetExecutionEntry\x12\x39.qwak.feature.store.execution.v1.GetExecutionEntryRequest\x1a:.qwak.feature.store.execution.v1.GetExecutionEntryResponse\x12\xa5\x01\n\x1aGetRunningExecutionEntries\x12\x42.qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest\x1a\x43.qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse\x12\xab\x01\n\x1cInitPaginationByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse\x12\xab\x01\n\x1cListExecutionsByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponseB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')



_TRIGGERBACKFILLREQUEST = DESCRIPTOR.message_types_by_name['TriggerBackfillRequest']
_TRIGGERBACKFILLRESPONSE = DESCRIPTOR.message_types_by_name['TriggerBackfillResponse']
_GETEXECUTIONSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetExecutionStatusRequest']
_GETEXECUTIONSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetExecutionStatusResponse']
_GETEXECUTIONENTRYREQUEST = DESCRIPTOR.message_types_by_name['GetExecutionEntryRequest']
_GETEXECUTIONENTRYRESPONSE = DESCRIPTOR.message_types_by_name['GetExecutionEntryResponse']
_TRIGGERBATCHFEATURESETREQUEST = DESCRIPTOR.message_types_by_name['TriggerBatchFeaturesetRequest']
_TRIGGERBATCHFEATURESETRESPONSE = DESCRIPTOR.message_types_by_name['TriggerBatchFeaturesetResponse']
_GETRUNNINGEXECUTIONENTRIESREQUEST = DESCRIPTOR.message_types_by_name['GetRunningExecutionEntriesRequest']
_GETRUNNINGEXECUTIONENTRIESRESPONSE = DESCRIPTOR.message_types_by_name['GetRunningExecutionEntriesResponse']
_TRIGGERFEATURESETDELETIONREQUEST = DESCRIPTOR.message_types_by_name['TriggerFeaturesetDeletionRequest']
_TRIGGERFEATURESETDELETIONRESPONSE = DESCRIPTOR.message_types_by_name['TriggerFeaturesetDeletionResponse']
_INITPAGINATIONBYFEATURESETIDREQUEST = DESCRIPTOR.message_types_by_name['InitPaginationByFeaturesetIdRequest']
_INITPAGINATIONBYFEATURESETIDRESPONSE = DESCRIPTOR.message_types_by_name['InitPaginationByFeaturesetIdResponse']
_LISTEXECUTIONSBYFEATURESETIDREQUEST = DESCRIPTOR.message_types_by_name['ListExecutionsByFeaturesetIdRequest']
_LISTEXECUTIONSBYFEATURESETIDRESPONSE = DESCRIPTOR.message_types_by_name['ListExecutionsByFeaturesetIdResponse']
TriggerBackfillRequest = _reflection.GeneratedProtocolMessageType('TriggerBackfillRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBACKFILLREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBackfillRequest)
  })
_sym_db.RegisterMessage(TriggerBackfillRequest)

TriggerBackfillResponse = _reflection.GeneratedProtocolMessageType('TriggerBackfillResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBACKFILLRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBackfillResponse)
  })
_sym_db.RegisterMessage(TriggerBackfillResponse)

GetExecutionStatusRequest = _reflection.GeneratedProtocolMessageType('GetExecutionStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONSTATUSREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionStatusRequest)
  })
_sym_db.RegisterMessage(GetExecutionStatusRequest)

GetExecutionStatusResponse = _reflection.GeneratedProtocolMessageType('GetExecutionStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONSTATUSRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionStatusResponse)
  })
_sym_db.RegisterMessage(GetExecutionStatusResponse)

GetExecutionEntryRequest = _reflection.GeneratedProtocolMessageType('GetExecutionEntryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENTRYREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionEntryRequest)
  })
_sym_db.RegisterMessage(GetExecutionEntryRequest)

GetExecutionEntryResponse = _reflection.GeneratedProtocolMessageType('GetExecutionEntryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETEXECUTIONENTRYRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetExecutionEntryResponse)
  })
_sym_db.RegisterMessage(GetExecutionEntryResponse)

TriggerBatchFeaturesetRequest = _reflection.GeneratedProtocolMessageType('TriggerBatchFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBATCHFEATURESETREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest)
  })
_sym_db.RegisterMessage(TriggerBatchFeaturesetRequest)

TriggerBatchFeaturesetResponse = _reflection.GeneratedProtocolMessageType('TriggerBatchFeaturesetResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERBATCHFEATURESETRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse)
  })
_sym_db.RegisterMessage(TriggerBatchFeaturesetResponse)

GetRunningExecutionEntriesRequest = _reflection.GeneratedProtocolMessageType('GetRunningExecutionEntriesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNNINGEXECUTIONENTRIESREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest)
  })
_sym_db.RegisterMessage(GetRunningExecutionEntriesRequest)

GetRunningExecutionEntriesResponse = _reflection.GeneratedProtocolMessageType('GetRunningExecutionEntriesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNNINGEXECUTIONENTRIESRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse)
  })
_sym_db.RegisterMessage(GetRunningExecutionEntriesResponse)

TriggerFeaturesetDeletionRequest = _reflection.GeneratedProtocolMessageType('TriggerFeaturesetDeletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERFEATURESETDELETIONREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest)
  })
_sym_db.RegisterMessage(TriggerFeaturesetDeletionRequest)

TriggerFeaturesetDeletionResponse = _reflection.GeneratedProtocolMessageType('TriggerFeaturesetDeletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERFEATURESETDELETIONRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse)
  })
_sym_db.RegisterMessage(TriggerFeaturesetDeletionResponse)

InitPaginationByFeaturesetIdRequest = _reflection.GeneratedProtocolMessageType('InitPaginationByFeaturesetIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYFEATURESETIDREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest)
  })
_sym_db.RegisterMessage(InitPaginationByFeaturesetIdRequest)

InitPaginationByFeaturesetIdResponse = _reflection.GeneratedProtocolMessageType('InitPaginationByFeaturesetIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _INITPAGINATIONBYFEATURESETIDRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse)
  })
_sym_db.RegisterMessage(InitPaginationByFeaturesetIdResponse)

ListExecutionsByFeaturesetIdRequest = _reflection.GeneratedProtocolMessageType('ListExecutionsByFeaturesetIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTIONSBYFEATURESETIDREQUEST,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest)
  })
_sym_db.RegisterMessage(ListExecutionsByFeaturesetIdRequest)

ListExecutionsByFeaturesetIdResponse = _reflection.GeneratedProtocolMessageType('ListExecutionsByFeaturesetIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEXECUTIONSBYFEATURESETIDRESPONSE,
  '__module__' : 'qwak.execution.v1.execution_service_pb2'
  # @@protoc_insertion_point(class_scope:qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponse)
  })
_sym_db.RegisterMessage(ListExecutionsByFeaturesetIdResponse)

_FEATURESTOREEXECUTIONSERVICE = DESCRIPTOR.services_by_name['FeatureStoreExecutionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _TRIGGERBACKFILLREQUEST._serialized_start=212
  _TRIGGERBACKFILLREQUEST._serialized_end=306
  _TRIGGERBACKFILLRESPONSE._serialized_start=308
  _TRIGGERBACKFILLRESPONSE._serialized_end=355
  _GETEXECUTIONSTATUSREQUEST._serialized_start=357
  _GETEXECUTIONSTATUSREQUEST._serialized_end=406
  _GETEXECUTIONSTATUSRESPONSE._serialized_start=408
  _GETEXECUTIONSTATUSRESPONSE._serialized_end=512
  _GETEXECUTIONENTRYREQUEST._serialized_start=514
  _GETEXECUTIONENTRYREQUEST._serialized_end=562
  _GETEXECUTIONENTRYRESPONSE._serialized_start=564
  _GETEXECUTIONENTRYRESPONSE._serialized_end=665
  _TRIGGERBATCHFEATURESETREQUEST._serialized_start=667
  _TRIGGERBATCHFEATURESETREQUEST._serialized_end=772
  _TRIGGERBATCHFEATURESETRESPONSE._serialized_start=774
  _TRIGGERBATCHFEATURESETRESPONSE._serialized_end=828
  _GETRUNNINGEXECUTIONENTRIESREQUEST._serialized_start=830
  _GETRUNNINGEXECUTIONENTRIESREQUEST._serialized_end=888
  _GETRUNNINGEXECUTIONENTRIESRESPONSE._serialized_start=890
  _GETRUNNINGEXECUTIONENTRIESRESPONSE._serialized_end=1002
  _TRIGGERFEATURESETDELETIONREQUEST._serialized_start=1004
  _TRIGGERFEATURESETDELETIONREQUEST._serialized_end=1061
  _TRIGGERFEATURESETDELETIONRESPONSE._serialized_start=1063
  _TRIGGERFEATURESETDELETIONRESPONSE._serialized_end=1120
  _INITPAGINATIONBYFEATURESETIDREQUEST._serialized_start=1122
  _INITPAGINATIONBYFEATURESETIDREQUEST._serialized_end=1182
  _INITPAGINATIONBYFEATURESETIDRESPONSE._serialized_start=1184
  _INITPAGINATIONBYFEATURESETIDRESPONSE._serialized_end=1273
  _LISTEXECUTIONSBYFEATURESETIDREQUEST._serialized_start=1276
  _LISTEXECUTIONSBYFEATURESETIDREQUEST._serialized_end=1405
  _LISTEXECUTIONSBYFEATURESETIDRESPONSE._serialized_start=1407
  _LISTEXECUTIONSBYFEATURESETIDRESPONSE._serialized_end=1521
  _FEATURESTOREEXECUTIONSERVICE._serialized_start=1524
  _FEATURESTOREEXECUTIONSERVICE._serialized_end=2816
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.builds.build_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BuildStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BuildStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BuildStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _BuildStatus.ValueType  # 0
    """An invalid state build status, the default if unset"""
    IN_PROGRESS: _BuildStatus.ValueType  # 1
    """Build is in progress"""
    SUCCESSFUL: _BuildStatus.ValueType  # 2
    """Build is successful"""
    FAILED: _BuildStatus.ValueType  # 3
    """Build failed"""
    REMOTE_BUILD_INITIALIZING: _BuildStatus.ValueType  # 4
    """Remote build is initializing"""
    REMOTE_BUILD_CANCELLED: _BuildStatus.ValueType  # 5
    """Remote build status is cancelled"""
    REMOTE_BUILD_TIMED_OUT: _BuildStatus.ValueType  # 6
    """Remote build status is timed out"""
    REMOTE_BUILD_UNKNOWN: _BuildStatus.ValueType  # 7
    """Remote build is unknown"""
    SYNCING_ENVIRONMENTS: _BuildStatus.ValueType  # 8
    """Build image is syncing between environments"""
    FINISHED_SYNCING: _BuildStatus.ValueType  # 9
    """Build artifact is synced and ready"""

class BuildStatus(_BuildStatus, metaclass=_BuildStatusEnumTypeWrapper): ...

INVALID: BuildStatus.ValueType  # 0
"""An invalid state build status, the default if unset"""
IN_PROGRESS: BuildStatus.ValueType  # 1
"""Build is in progress"""
SUCCESSFUL: BuildStatus.ValueType  # 2
"""Build is successful"""
FAILED: BuildStatus.ValueType  # 3
"""Build failed"""
REMOTE_BUILD_INITIALIZING: BuildStatus.ValueType  # 4
"""Remote build is initializing"""
REMOTE_BUILD_CANCELLED: BuildStatus.ValueType  # 5
"""Remote build status is cancelled"""
REMOTE_BUILD_TIMED_OUT: BuildStatus.ValueType  # 6
"""Remote build status is timed out"""
REMOTE_BUILD_UNKNOWN: BuildStatus.ValueType  # 7
"""Remote build is unknown"""
SYNCING_ENVIRONMENTS: BuildStatus.ValueType  # 8
"""Build image is syncing between environments"""
FINISHED_SYNCING: BuildStatus.ValueType  # 9
"""Build artifact is synced and ready"""
global___BuildStatus = BuildStatus

class _MetricOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _MetricOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_MetricOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    METRIC_OPERATOR_TYPE_INVALID: _MetricOperatorType.ValueType  # 0
    METRIC_OPERATOR_TYPE_EQUALS: _MetricOperatorType.ValueType  # 1
    METRIC_OPERATOR_TYPE_NOT_EQUALS: _MetricOperatorType.ValueType  # 2
    METRIC_OPERATOR_TYPE_LESS_THAN: _MetricOperatorType.ValueType  # 3
    METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS: _MetricOperatorType.ValueType  # 4
    METRIC_OPERATOR_TYPE_GREATER_THAN: _MetricOperatorType.ValueType  # 5
    METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS: _MetricOperatorType.ValueType  # 6

class MetricOperatorType(_MetricOperatorType, metaclass=_MetricOperatorTypeEnumTypeWrapper): ...

METRIC_OPERATOR_TYPE_INVALID: MetricOperatorType.ValueType  # 0
METRIC_OPERATOR_TYPE_EQUALS: MetricOperatorType.ValueType  # 1
METRIC_OPERATOR_TYPE_NOT_EQUALS: MetricOperatorType.ValueType  # 2
METRIC_OPERATOR_TYPE_LESS_THAN: MetricOperatorType.ValueType  # 3
METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS: MetricOperatorType.ValueType  # 4
METRIC_OPERATOR_TYPE_GREATER_THAN: MetricOperatorType.ValueType  # 5
METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS: MetricOperatorType.ValueType  # 6
global___MetricOperatorType = MetricOperatorType

class _ParameterOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ParameterOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ParameterOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PARAMETER_OPERATOR_TYPE_INVALID: _ParameterOperatorType.ValueType  # 0
    PARAMETER_OPERATOR_TYPE_EQUALS: _ParameterOperatorType.ValueType  # 1
    PARAMETER_OPERATOR_TYPE_NOT_EQUALS: _ParameterOperatorType.ValueType  # 2

class ParameterOperatorType(_ParameterOperatorType, metaclass=_ParameterOperatorTypeEnumTypeWrapper): ...

PARAMETER_OPERATOR_TYPE_INVALID: ParameterOperatorType.ValueType  # 0
PARAMETER_OPERATOR_TYPE_EQUALS: ParameterOperatorType.ValueType  # 1
PARAMETER_OPERATOR_TYPE_NOT_EQUALS: ParameterOperatorType.ValueType  # 2
global___ParameterOperatorType = ParameterOperatorType

class ModelSchema(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_FIELD_NUMBER: builtins.int
    FEATURES_FIELD_NUMBER: builtins.int
    PREDICTIONS_FIELD_NUMBER: builtins.int
    INFERENCE_OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def entities(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Entity]:
        """list of model entities"""
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feature]:
        """list of model features (Explicit / Batch / OnTheFly)"""
    @property
    def predictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Prediction]:
        """List of model predictions (Model output)"""
    @property
    def inference_output(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InferenceOutput]:
        """List of model predictions (Model output)"""
    def __init__(
        self,
        *,
        entities: collections.abc.Iterable[global___Entity] | None = ...,
        features: collections.abc.Iterable[global___Feature] | None = ...,
        predictions: collections.abc.Iterable[global___Prediction] | None = ...,
        inference_output: collections.abc.Iterable[global___InferenceOutput] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities", b"entities", "features", b"features", "inference_output", b"inference_output", "predictions", b"predictions"]) -> None: ...

global___ModelSchema = ModelSchema

class Entity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Entity name"""
    @property
    def type(self) -> global___ValueType:
        """Entity type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___Entity = Entity

class Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_FEATURE_FIELD_NUMBER: builtins.int
    EXPLICIT_FEATURE_FIELD_NUMBER: builtins.int
    ON_THE_FLY_FEATURE_FIELD_NUMBER: builtins.int
    STREAMING_FEATURE_FIELD_NUMBER: builtins.int
    REQUEST_INPUT_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_FEATURE_FIELD_NUMBER: builtins.int
    BATCH_FEATURE_V1_FIELD_NUMBER: builtins.int
    STREAMING_FEATURE_V1_FIELD_NUMBER: builtins.int
    @property
    def batch_feature(self) -> global___BatchFeature: ...
    @property
    def explicit_feature(self) -> global___ExplicitFeature: ...
    @property
    def on_the_fly_feature(self) -> global___OnTheFlyFeature: ...
    @property
    def streaming_feature(self) -> global___StreamingFeature: ...
    @property
    def request_input(self) -> global___RequestInput: ...
    @property
    def streaming_aggregation_feature(self) -> global___StreamingAggregationFeature: ...
    @property
    def batch_feature_v1(self) -> global___BatchFeatureV1: ...
    @property
    def streaming_feature_v1(self) -> global___StreamingFeatureV1: ...
    def __init__(
        self,
        *,
        batch_feature: global___BatchFeature | None = ...,
        explicit_feature: global___ExplicitFeature | None = ...,
        on_the_fly_feature: global___OnTheFlyFeature | None = ...,
        streaming_feature: global___StreamingFeature | None = ...,
        request_input: global___RequestInput | None = ...,
        streaming_aggregation_feature: global___StreamingAggregationFeature | None = ...,
        batch_feature_v1: global___BatchFeatureV1 | None = ...,
        streaming_feature_v1: global___StreamingFeatureV1 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_feature", b"batch_feature", "batch_feature_v1", b"batch_feature_v1", "explicit_feature", b"explicit_feature", "on_the_fly_feature", b"on_the_fly_feature", "request_input", b"request_input", "streaming_aggregation_feature", b"streaming_aggregation_feature", "streaming_feature", b"streaming_feature", "streaming_feature_v1", b"streaming_feature_v1", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_feature", b"batch_feature", "batch_feature_v1", b"batch_feature_v1", "explicit_feature", b"explicit_feature", "on_the_fly_feature", b"on_the_fly_feature", "request_input", b"request_input", "streaming_aggregation_feature", b"streaming_aggregation_feature", "streaming_feature", b"streaming_feature", "streaming_feature_v1", b"streaming_feature_v1", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["batch_feature", "explicit_feature", "on_the_fly_feature", "streaming_feature", "request_input", "streaming_aggregation_feature", "batch_feature_v1", "streaming_feature_v1"] | None: ...

global___Feature = Feature

class OnTheFlyFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FEATURES_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    @property
    def source_features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SourceFeature]:
        """The source feature on the fly build on"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
        source_features: collections.abc.Iterable[global___SourceFeature] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name", "source_features", b"source_features"]) -> None: ...

global___OnTheFlyFeature = OnTheFlyFeature

class BatchFeatureV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name"]) -> None: ...

global___BatchFeatureV1 = BatchFeatureV1

class StreamingFeatureV1(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name"]) -> None: ...

global___StreamingFeatureV1 = StreamingFeatureV1

class BatchFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name"]) -> None: ...

global___BatchFeature = BatchFeature

class StreamingFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name"]) -> None: ...

global___StreamingFeature = StreamingFeature

class StreamingAggregationFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def entity(self) -> global___Entity:
        """Qwak feature_store entity"""
    name: builtins.str
    """Feature name"""
    def __init__(
        self,
        *,
        entity: global___Entity | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "name", b"name"]) -> None: ...

global___StreamingAggregationFeature = StreamingAggregationFeature

class ExplicitFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Feature name"""
    @property
    def type(self) -> global___ValueType:
        """Feature type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___ExplicitFeature = ExplicitFeature

class RequestInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Feature name"""
    @property
    def type(self) -> global___ValueType:
        """Feature type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___RequestInput = RequestInput

class SourceFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXPLICIT_FEATURE_FIELD_NUMBER: builtins.int
    REQUEST_INPUT_FIELD_NUMBER: builtins.int
    @property
    def explicit_feature(self) -> global___ExplicitFeature: ...
    @property
    def request_input(self) -> global___RequestInput: ...
    def __init__(
        self,
        *,
        explicit_feature: global___ExplicitFeature | None = ...,
        request_input: global___RequestInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["explicit_feature", b"explicit_feature", "request_input", b"request_input", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["explicit_feature", b"explicit_feature", "request_input", b"request_input", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["explicit_feature", "request_input"] | None: ...

global___SourceFeature = SourceFeature

class Prediction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Prediction name"""
    @property
    def type(self) -> global___ValueType:
        """Prediction type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___Prediction = Prediction

class InferenceOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Prediction name"""
    @property
    def type(self) -> global___ValueType:
        """Prediction type"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "type", b"type"]) -> None: ...

global___InferenceOutput = InferenceOutput

class ValueType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Types:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypesEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ValueType._Types.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: ValueType._Types.ValueType  # 0
        BYTES: ValueType._Types.ValueType  # 1
        STRING: ValueType._Types.ValueType  # 2
        INT32: ValueType._Types.ValueType  # 3
        INT64: ValueType._Types.ValueType  # 4
        DOUBLE: ValueType._Types.ValueType  # 5
        FLOAT: ValueType._Types.ValueType  # 6
        BOOL: ValueType._Types.ValueType  # 7

    class Types(_Types, metaclass=_TypesEnumTypeWrapper): ...
    INVALID: ValueType.Types.ValueType  # 0
    BYTES: ValueType.Types.ValueType  # 1
    STRING: ValueType.Types.ValueType  # 2
    INT32: ValueType.Types.ValueType  # 3
    INT64: ValueType.Types.ValueType  # 4
    DOUBLE: ValueType.Types.ValueType  # 5
    FLOAT: ValueType.Types.ValueType  # 6
    BOOL: ValueType.Types.ValueType  # 7

    TYPE_FIELD_NUMBER: builtins.int
    type: global___ValueType.Types.ValueType
    def __init__(
        self,
        *,
        type: global___ValueType.Types.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ValueType = ValueType

class ParameterCategory(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Category:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CategoryEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ParameterCategory._Category.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID: ParameterCategory._Category.ValueType  # 0
        """An invalid parameter type, the default if unset"""
        ENTITY: ParameterCategory._Category.ValueType  # 1
        """Entity parameter"""
        FEATURE: ParameterCategory._Category.ValueType  # 2
        """Feature parameter"""
        PREDICTION: ParameterCategory._Category.ValueType  # 3
        """Prediction parameter"""
        INFERENCEOUTPUT: ParameterCategory._Category.ValueType  # 4
        """New Prediction parameter"""

    class Category(_Category, metaclass=_CategoryEnumTypeWrapper): ...
    INVALID: ParameterCategory.Category.ValueType  # 0
    """An invalid parameter type, the default if unset"""
    ENTITY: ParameterCategory.Category.ValueType  # 1
    """Entity parameter"""
    FEATURE: ParameterCategory.Category.ValueType  # 2
    """Feature parameter"""
    PREDICTION: ParameterCategory.Category.ValueType  # 3
    """Prediction parameter"""
    INFERENCEOUTPUT: ParameterCategory.Category.ValueType  # 4
    """New Prediction parameter"""

    def __init__(
        self,
    ) -> None: ...

global___ParameterCategory = ParameterCategory

class Build(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class ParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class MetricsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.float
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUILDID_FIELD_NUMBER: builtins.int
    COMMITID_FIELD_NUMBER: builtins.int
    BRANCHID_FIELD_NUMBER: builtins.int
    BUILDCONFIG_FIELD_NUMBER: builtins.int
    BUILD_STATUS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    STEPS_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    MODEL_SCHEMA_FIELD_NUMBER: builtins.int
    AUDIT_FIELD_NUMBER: builtins.int
    MODEL_UUID_FIELD_NUMBER: builtins.int
    SDK_VERSION_FIELD_NUMBER: builtins.int
    IMAGE_NAME_TAG_FIELD_NUMBER: builtins.int
    BUILD_CONFIGURATION_MESSAGE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    BUILD_DESTINED_IMAGE_FIELD_NUMBER: builtins.int
    FRAMEWORK_MODELS_FIELD_NUMBER: builtins.int
    BUILD_DESTINED_IMAGE_PULL_SECRET_FIELD_NUMBER: builtins.int
    FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    buildId: builtins.str
    commitId: builtins.str
    branchId: builtins.str
    buildConfig: builtins.str
    build_status: global___BuildStatus.ValueType
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def metrics(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.float]: ...
    @property
    def model_schema(self) -> global___ModelSchema: ...
    @property
    def audit(self) -> global___Audit: ...
    model_uuid: builtins.str
    sdk_version: builtins.str
    image_name_tag: builtins.str
    @property
    def build_configuration_message(self) -> global___BuildConfiguration: ...
    @property
    def end_date(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End date of build"""
    environment_id: builtins.str
    build_destined_image: builtins.str
    @property
    def framework_models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrameworkModel]: ...
    build_destined_image_pull_secret: builtins.str
    """The name of pull secret if needed"""
    failure_reason_code: builtins.str
    """Failure reason code if we recognize it."""
    def __init__(
        self,
        *,
        buildId: builtins.str = ...,
        commitId: builtins.str = ...,
        branchId: builtins.str = ...,
        buildConfig: builtins.str = ...,
        build_status: global___BuildStatus.ValueType = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        steps: collections.abc.Iterable[builtins.str] | None = ...,
        params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        metrics: collections.abc.Mapping[builtins.str, builtins.float] | None = ...,
        model_schema: global___ModelSchema | None = ...,
        audit: global___Audit | None = ...,
        model_uuid: builtins.str = ...,
        sdk_version: builtins.str = ...,
        image_name_tag: builtins.str = ...,
        build_configuration_message: global___BuildConfiguration | None = ...,
        end_date: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        environment_id: builtins.str = ...,
        build_destined_image: builtins.str = ...,
        framework_models: collections.abc.Iterable[global___FrameworkModel] | None = ...,
        build_destined_image_pull_secret: builtins.str = ...,
        failure_reason_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audit", b"audit", "build_configuration_message", b"build_configuration_message", "end_date", b"end_date", "model_schema", b"model_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audit", b"audit", "branchId", b"branchId", "buildConfig", b"buildConfig", "buildId", b"buildId", "build_configuration_message", b"build_configuration_message", "build_destined_image", b"build_destined_image", "build_destined_image_pull_secret", b"build_destined_image_pull_secret", "build_status", b"build_status", "commitId", b"commitId", "end_date", b"end_date", "environment_id", b"environment_id", "failure_reason_code", b"failure_reason_code", "framework_models", b"framework_models", "image_name_tag", b"image_name_tag", "metrics", b"metrics", "model_schema", b"model_schema", "model_uuid", b"model_uuid", "params", b"params", "sdk_version", b"sdk_version", "steps", b"steps", "tags", b"tags"]) -> None: ...

global___Build = Build

class Audit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    created_by: builtins.str
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    last_modified_by: builtins.str
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        created_by: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_by: builtins.str = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by"]) -> None: ...

global___Audit = Audit

class BuildConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_PROPERTIES_FIELD_NUMBER: builtins.int
    BUILD_ENV_FIELD_NUMBER: builtins.int
    PRE_BUILD_FIELD_NUMBER: builtins.int
    POST_BUILD_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    VERBOSE_FIELD_NUMBER: builtins.int
    @property
    def build_properties(self) -> global___BuildProperties: ...
    @property
    def build_env(self) -> global___BuildEnvironment: ...
    @property
    def pre_build(self) -> global___BuildEnvironment: ...
    @property
    def post_build(self) -> global___BuildEnvironment: ...
    @property
    def step(self) -> global___Step: ...
    verbose: builtins.int
    def __init__(
        self,
        *,
        build_properties: global___BuildProperties | None = ...,
        build_env: global___BuildEnvironment | None = ...,
        pre_build: global___BuildEnvironment | None = ...,
        post_build: global___BuildEnvironment | None = ...,
        step: global___Step | None = ...,
        verbose: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["build_env", b"build_env", "build_properties", b"build_properties", "post_build", b"post_build", "pre_build", b"pre_build", "step", b"step"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_env", b"build_env", "build_properties", b"build_properties", "post_build", b"post_build", "pre_build", b"pre_build", "step", b"step", "verbose", b"verbose"]) -> None: ...

global___BuildConfiguration = BuildConfiguration

class BuildProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    MODEL_URI_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    BRANCH_FIELD_NUMBER: builtins.int
    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    GPU_COMPATIBLE_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    @property
    def model_uri(self) -> global___BuildModelUri: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    build_id: builtins.str
    branch: builtins.str
    environment_name: builtins.str
    gpu_compatible: builtins.bool
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        model_uri: global___BuildModelUri | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        build_id: builtins.str = ...,
        branch: builtins.str = ...,
        environment_name: builtins.str = ...,
        gpu_compatible: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model_uri", b"model_uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "build_id", b"build_id", "environment_name", b"environment_name", "gpu_compatible", b"gpu_compatible", "model_id", b"model_id", "model_uri", b"model_uri", "tags", b"tags"]) -> None: ...

global___BuildProperties = BuildProperties

class BuildModelUri(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URI_FIELD_NUMBER: builtins.int
    GIT_BRANCH_FIELD_NUMBER: builtins.int
    MAIN_DIR_FIELD_NUMBER: builtins.int
    DEPENDENCY_REQUIRED_FOLDERS_FIELD_NUMBER: builtins.int
    uri: builtins.str
    git_branch: builtins.str
    main_dir: builtins.str
    @property
    def dependency_required_folders(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        uri: builtins.str = ...,
        git_branch: builtins.str = ...,
        main_dir: builtins.str = ...,
        dependency_required_folders: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dependency_required_folders", b"dependency_required_folders", "git_branch", b"git_branch", "main_dir", b"main_dir", "uri", b"uri"]) -> None: ...

global___BuildModelUri = BuildModelUri

class BuildEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOCKER_FIELD_NUMBER: builtins.int
    LOCAL_FIELD_NUMBER: builtins.int
    PYTHON_ENV_FIELD_NUMBER: builtins.int
    REMOTE_FIELD_NUMBER: builtins.int
    @property
    def docker(self) -> global___DockerBuild: ...
    @property
    def local(self) -> global___LocalBuild: ...
    @property
    def python_env(self) -> global___PythonBuild: ...
    @property
    def remote(self) -> global___RemoteBuild: ...
    def __init__(
        self,
        *,
        docker: global___DockerBuild | None = ...,
        local: global___LocalBuild | None = ...,
        python_env: global___PythonBuild | None = ...,
        remote: global___RemoteBuild | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["docker", b"docker", "local", b"local", "python_env", b"python_env", "remote", b"remote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["docker", b"docker", "local", b"local", "python_env", b"python_env", "remote", b"remote"]) -> None: ...

global___BuildEnvironment = BuildEnvironment

class DockerBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class BuildArgsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BASE_IMAGE_FIELD_NUMBER: builtins.int
    BUILD_ARGS_FIELD_NUMBER: builtins.int
    ENV_VARS_FIELD_NUMBER: builtins.int
    NO_CACHE_FIELD_NUMBER: builtins.int
    PARAMS_FIELD_NUMBER: builtins.int
    ASSUMED_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    CACHE_FIELD_NUMBER: builtins.int
    PUSH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    base_image: builtins.str
    @property
    def build_args(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def env_vars(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    no_cache: builtins.bool
    @property
    def params(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    assumed_iam_role_arn: builtins.str
    cache: builtins.bool
    push: builtins.bool
    service_account_key_secret_name: builtins.str
    def __init__(
        self,
        *,
        base_image: builtins.str = ...,
        build_args: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        env_vars: collections.abc.Iterable[builtins.str] | None = ...,
        no_cache: builtins.bool = ...,
        params: collections.abc.Iterable[builtins.str] | None = ...,
        assumed_iam_role_arn: builtins.str = ...,
        cache: builtins.bool = ...,
        push: builtins.bool = ...,
        service_account_key_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assumed_iam_role_arn", b"assumed_iam_role_arn", "base_image", b"base_image", "build_args", b"build_args", "cache", b"cache", "env_vars", b"env_vars", "no_cache", b"no_cache", "params", b"params", "push", b"push", "service_account_key_secret_name", b"service_account_key_secret_name"]) -> None: ...

global___DockerBuild = DockerBuild

class LocalBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_PROFILE_FIELD_NUMBER: builtins.int
    NO_PUSH_FIELD_NUMBER: builtins.int
    aws_profile: builtins.str
    no_push: builtins.bool
    def __init__(
        self,
        *,
        aws_profile: builtins.str = ...,
        no_push: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_profile", b"aws_profile", "no_push", b"no_push"]) -> None: ...

global___LocalBuild = LocalBuild

class PythonBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QWAK_SDK_EXTRA_INDEX_URL_FIELD_NUMBER: builtins.int
    VIRTUALENV_FIELD_NUMBER: builtins.int
    CONDA_FIELD_NUMBER: builtins.int
    POETRY_FIELD_NUMBER: builtins.int
    DEPENDENCY_FILE_PATH_FIELD_NUMBER: builtins.int
    USE_DEPRECATED_RESOLVER_FIELD_NUMBER: builtins.int
    qwak_sdk_extra_index_url: builtins.str
    @property
    def virtualenv(self) -> global___VirtualEnvironmentBuild: ...
    @property
    def conda(self) -> global___CondaBuild: ...
    @property
    def poetry(self) -> global___PoetryBuild: ...
    dependency_file_path: builtins.str
    use_deprecated_resolver: builtins.bool
    def __init__(
        self,
        *,
        qwak_sdk_extra_index_url: builtins.str = ...,
        virtualenv: global___VirtualEnvironmentBuild | None = ...,
        conda: global___CondaBuild | None = ...,
        poetry: global___PoetryBuild | None = ...,
        dependency_file_path: builtins.str = ...,
        use_deprecated_resolver: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["conda", b"conda", "poetry", b"poetry", "virtualenv", b"virtualenv"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conda", b"conda", "dependency_file_path", b"dependency_file_path", "poetry", b"poetry", "qwak_sdk_extra_index_url", b"qwak_sdk_extra_index_url", "use_deprecated_resolver", b"use_deprecated_resolver", "virtualenv", b"virtualenv"]) -> None: ...

global___PythonBuild = PythonBuild

class CondaBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDA_FILE_FIELD_NUMBER: builtins.int
    conda_file: builtins.str
    def __init__(
        self,
        *,
        conda_file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["conda_file", b"conda_file"]) -> None: ...

global___CondaBuild = CondaBuild

class PoetryBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    LOCK_FILE_FIELD_NUMBER: builtins.int
    python_version: builtins.str
    lock_file: builtins.str
    def __init__(
        self,
        *,
        python_version: builtins.str = ...,
        lock_file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock_file", b"lock_file", "python_version", b"python_version"]) -> None: ...

global___PoetryBuild = PoetryBuild

class VirtualEnvironmentBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    REQUIREMENTS_TXT_FIELD_NUMBER: builtins.int
    python_version: builtins.str
    requirements_txt: builtins.str
    def __init__(
        self,
        *,
        python_version: builtins.str = ...,
        requirements_txt: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["python_version", b"python_version", "requirements_txt", b"requirements_txt"]) -> None: ...

global___VirtualEnvironmentBuild = VirtualEnvironmentBuild

class RemoteBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_REMOTE_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    is_remote: builtins.bool
    @property
    def resources(self) -> global___RemoteBuildResources: ...
    def __init__(
        self,
        *,
        is_remote: builtins.bool = ...,
        resources: global___RemoteBuildResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_remote", b"is_remote", "resources", b"resources"]) -> None: ...

global___RemoteBuild = RemoteBuild

class RemoteBuildResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPUS_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    GPU_TYPE_FIELD_NUMBER: builtins.int
    GPU_AMOUNT_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    cpus: builtins.float
    memory: builtins.str
    gpu_type: qwak.builds.build_pb2.GpuType.ValueType
    gpu_amount: builtins.int
    instance: builtins.str
    def __init__(
        self,
        *,
        cpus: builtins.float = ...,
        memory: builtins.str = ...,
        gpu_type: qwak.builds.build_pb2.GpuType.ValueType = ...,
        gpu_amount: builtins.int = ...,
        instance: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpus", b"cpus", "gpu_amount", b"gpu_amount", "gpu_type", b"gpu_type", "instance", b"instance", "memory", b"memory"]) -> None: ...

global___RemoteBuildResources = RemoteBuildResources

class Step(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TESTS_FIELD_NUMBER: builtins.int
    VALIDATE_BUILD_ARTIFACT_FIELD_NUMBER: builtins.int
    VALIDATE_BUILD_ARTIFACT_TIMEOUT_FIELD_NUMBER: builtins.int
    tests: builtins.bool
    validate_build_artifact: builtins.bool
    validate_build_artifact_timeout: builtins.int
    def __init__(
        self,
        *,
        tests: builtins.bool = ...,
        validate_build_artifact: builtins.bool = ...,
        validate_build_artifact_timeout: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tests", b"tests", "validate_build_artifact", b"validate_build_artifact", "validate_build_artifact_timeout", b"validate_build_artifact_timeout"]) -> None: ...

global___Step = Step

class BuildFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGS_FIELD_NUMBER: builtins.int
    METRIC_FILTERS_FIELD_NUMBER: builtins.int
    PARAMETER_FILTERS_FIELD_NUMBER: builtins.int
    REQUIRE_ALL_TAGS_FIELD_NUMBER: builtins.int
    INCLUDE_EXTRA_TAGS_FIELD_NUMBER: builtins.int
    BUILD_IDS_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def metric_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MetricFilter]: ...
    @property
    def parameter_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ParameterFilter]: ...
    require_all_tags: builtins.bool
    include_extra_tags: builtins.bool
    @property
    def build_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        metric_filters: collections.abc.Iterable[global___MetricFilter] | None = ...,
        parameter_filters: collections.abc.Iterable[global___ParameterFilter] | None = ...,
        require_all_tags: builtins.bool = ...,
        include_extra_tags: builtins.bool = ...,
        build_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_ids", b"build_ids", "include_extra_tags", b"include_extra_tags", "metric_filters", b"metric_filters", "parameter_filters", b"parameter_filters", "require_all_tags", b"require_all_tags", "tags", b"tags"]) -> None: ...

global___BuildFilter = BuildFilter

class MetricFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_NAME_FIELD_NUMBER: builtins.int
    METRIC_VALUE_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    metric_name: builtins.str
    metric_value: builtins.float
    operator: global___MetricOperatorType.ValueType
    def __init__(
        self,
        *,
        metric_name: builtins.str = ...,
        metric_value: builtins.float = ...,
        operator: global___MetricOperatorType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_name", b"metric_name", "metric_value", b"metric_value", "operator", b"operator"]) -> None: ...

global___MetricFilter = MetricFilter

class ParameterFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMETER_NAME_FIELD_NUMBER: builtins.int
    PARAMETER_VALUE_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    parameter_name: builtins.str
    parameter_value: builtins.str
    operator: global___ParameterOperatorType.ValueType
    def __init__(
        self,
        *,
        parameter_name: builtins.str = ...,
        parameter_value: builtins.str = ...,
        operator: global___ParameterOperatorType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["operator", b"operator", "parameter_name", b"parameter_name", "parameter_value", b"parameter_value"]) -> None: ...

global___ParameterFilter = ParameterFilter

class FrameworkModelsSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    FRAMEWORK_MODELS_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    @property
    def framework_models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FrameworkModel]: ...
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        framework_models: collections.abc.Iterable[global___FrameworkModel] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "framework_models", b"framework_models"]) -> None: ...

global___FrameworkModelsSpec = FrameworkModelsSpec

class FrameworkModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HUGGINGFACE_MODEL_SPEC_FIELD_NUMBER: builtins.int
    @property
    def huggingface_model_spec(self) -> global___HuggingFaceModelSpec: ...
    def __init__(
        self,
        *,
        huggingface_model_spec: global___HuggingFaceModelSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["huggingface_model_spec", b"huggingface_model_spec", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["huggingface_model_spec", b"huggingface_model_spec", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["huggingface_model_spec"] | None: ...

global___FrameworkModel = FrameworkModel

class HuggingFaceModelSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    MODEL_NAME_FIELD_NUMBER: builtins.int
    SHA1_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Version of the model"""
    repository: builtins.str
    """The repository of"""
    model_name: builtins.str
    """model name"""
    sha1: builtins.str
    """The sha of the model"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        repository: builtins.str = ...,
        model_name: builtins.str = ...,
        sha1: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_name", b"model_name", "repository", b"repository", "sha1", b"sha1", "version", b"version"]) -> None: ...

global___HuggingFaceModelSpec = HuggingFaceModelSpec

class ScanResultSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ISSUES_FIELD_NUMBER: builtins.int
    UI_DIRECT_LINK_FIELD_NUMBER: builtins.int
    UI_SCAN_DIRECT_LINK_FIELD_NUMBER: builtins.int
    @property
    def issues(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Issue]:
        """List of issues"""
    ui_direct_link: builtins.str
    """Ui link scan result"""
    ui_scan_direct_link: builtins.str
    """direct scan link"""
    def __init__(
        self,
        *,
        issues: collections.abc.Iterable[global___Issue] | None = ...,
        ui_direct_link: builtins.str = ...,
        ui_scan_direct_link: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["issues", b"issues", "ui_direct_link", b"ui_direct_link", "ui_scan_direct_link", b"ui_scan_direct_link"]) -> None: ...

global___ScanResultSummary = ScanResultSummary

class Issue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SEVERITY_FIELD_NUMBER: builtins.int
    ISSUE_TYPE_FIELD_NUMBER: builtins.int
    SUMMARY_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the issue"""
    severity: builtins.str
    """The severity of the issue"""
    issue_type: builtins.str
    """The issue type"""
    summary: builtins.str
    """The summary"""
    description: builtins.str
    """The description"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        severity: builtins.str = ...,
        issue_type: builtins.str = ...,
        summary: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "issue_type", b"issue_type", "name", b"name", "severity", b"severity", "summary", b"summary"]) -> None: ...

global___Issue = Issue

class BuildImageDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FULL_PATH_FIELD_NUMBER: builtins.int
    IMAGE_PULL_SECRET_NAME_FIELD_NUMBER: builtins.int
    image_full_path: builtins.str
    image_pull_secret_name: builtins.str
    def __init__(
        self,
        *,
        image_full_path: builtins.str = ...,
        image_pull_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_full_path", b"image_full_path", "image_pull_secret_name", b"image_pull_secret_name"]) -> None: ...

global___BuildImageDetails = BuildImageDetails



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.administration.authenticated_user.v1.credentials_pb2
import qwak.batch_job.v1.batch_job_events_pb2
import qwak.user_application.common.v0.resources_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InputFileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InputFileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InputFileType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_INPUT_FILE_TYPE: _InputFileType.ValueType  # 0
    CSV_INPUT_FILE_TYPE: _InputFileType.ValueType  # 1
    FEATHER_INPUT_FILE_TYPE: _InputFileType.ValueType  # 2
    PARQUET_INPUT_FILE_TYPE: _InputFileType.ValueType  # 3

class InputFileType(_InputFileType, metaclass=_InputFileTypeEnumTypeWrapper): ...

UNDEFINED_INPUT_FILE_TYPE: InputFileType.ValueType  # 0
CSV_INPUT_FILE_TYPE: InputFileType.ValueType  # 1
FEATHER_INPUT_FILE_TYPE: InputFileType.ValueType  # 2
PARQUET_INPUT_FILE_TYPE: InputFileType.ValueType  # 3
global___InputFileType = InputFileType

class _OutputFileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OutputFileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OutputFileType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 0
    CSV_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 1
    FEATHER_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 2
    PARQUET_OUTPUT_FILE_TYPE: _OutputFileType.ValueType  # 3

class OutputFileType(_OutputFileType, metaclass=_OutputFileTypeEnumTypeWrapper): ...

UNDEFINED_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 0
CSV_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 1
FEATHER_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 2
PARQUET_OUTPUT_FILE_TYPE: OutputFileType.ValueType  # 3
global___OutputFileType = OutputFileType

class _BatchJobStatusMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchJobStatusMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchJobStatusMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_JOB_STATUS: _BatchJobStatusMessage.ValueType  # 0
    BATCH_JOB_COMMITTED_STATUS: _BatchJobStatusMessage.ValueType  # 1
    BATCH_JOB_PENDING_STATUS: _BatchJobStatusMessage.ValueType  # 2
    BATCH_JOB_RUNNING_STATUS: _BatchJobStatusMessage.ValueType  # 3
    BATCH_JOB_FINISHED_STATUS: _BatchJobStatusMessage.ValueType  # 4
    BATCH_JOB_FAILED_STATUS: _BatchJobStatusMessage.ValueType  # 5
    BATCH_JOB_CANCELLED_STATUS: _BatchJobStatusMessage.ValueType  # 6
    BATCH_JOB_TIMEOUT_STATUS: _BatchJobStatusMessage.ValueType  # 7

class BatchJobStatusMessage(_BatchJobStatusMessage, metaclass=_BatchJobStatusMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_JOB_STATUS: BatchJobStatusMessage.ValueType  # 0
BATCH_JOB_COMMITTED_STATUS: BatchJobStatusMessage.ValueType  # 1
BATCH_JOB_PENDING_STATUS: BatchJobStatusMessage.ValueType  # 2
BATCH_JOB_RUNNING_STATUS: BatchJobStatusMessage.ValueType  # 3
BATCH_JOB_FINISHED_STATUS: BatchJobStatusMessage.ValueType  # 4
BATCH_JOB_FAILED_STATUS: BatchJobStatusMessage.ValueType  # 5
BATCH_JOB_CANCELLED_STATUS: BatchJobStatusMessage.ValueType  # 6
BATCH_JOB_TIMEOUT_STATUS: BatchJobStatusMessage.ValueType  # 7
global___BatchJobStatusMessage = BatchJobStatusMessage

class _BatchTaskStatusMessage:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BatchTaskStatusMessageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BatchTaskStatusMessage.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNDEFINED_BATCH_TASK_STATUS: _BatchTaskStatusMessage.ValueType  # 0
    BATCH_TASK_COMMITTED_STATUS: _BatchTaskStatusMessage.ValueType  # 1
    BATCH_TASK_PENDING_START_STATUS: _BatchTaskStatusMessage.ValueType  # 2
    BATCH_TASK_RUNNING_STATUS: _BatchTaskStatusMessage.ValueType  # 3
    BATCH_TASK_FINISHED_STATUS: _BatchTaskStatusMessage.ValueType  # 4
    BATCH_TASK_FAILED_STATUS: _BatchTaskStatusMessage.ValueType  # 5
    BATCH_TASK_CANCELLED_STATUS: _BatchTaskStatusMessage.ValueType  # 6
    BATCH_TASK_TIMEOUT_STATUS: _BatchTaskStatusMessage.ValueType  # 7

class BatchTaskStatusMessage(_BatchTaskStatusMessage, metaclass=_BatchTaskStatusMessageEnumTypeWrapper): ...

UNDEFINED_BATCH_TASK_STATUS: BatchTaskStatusMessage.ValueType  # 0
BATCH_TASK_COMMITTED_STATUS: BatchTaskStatusMessage.ValueType  # 1
BATCH_TASK_PENDING_START_STATUS: BatchTaskStatusMessage.ValueType  # 2
BATCH_TASK_RUNNING_STATUS: BatchTaskStatusMessage.ValueType  # 3
BATCH_TASK_FINISHED_STATUS: BatchTaskStatusMessage.ValueType  # 4
BATCH_TASK_FAILED_STATUS: BatchTaskStatusMessage.ValueType  # 5
BATCH_TASK_CANCELLED_STATUS: BatchTaskStatusMessage.ValueType  # 6
BATCH_TASK_TIMEOUT_STATUS: BatchTaskStatusMessage.ValueType  # 7
global___BatchTaskStatusMessage = BatchTaskStatusMessage

class StartWarmupJobRequest(google.protobuf.message.Message):
    """Warmup job request. In order to spare the initialization time of a batch job, which is spinning up new instances
    and pulling the model image - we offer an optional 'warmup' with the intention of saving the aforementioned time
    when the batch job actually starts running
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    WARMUP_TIMEOUT_FIELD_NUMBER: builtins.int
    BATCH_JOB_DEPLOYMENT_SIZE_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """Model ID to start a batch"""
    branch_id: builtins.str
    """The branch ID of the model"""
    build_id: builtins.str
    """Specific build ID the warmup will be executed upon. If empty - deployed build ID will be the default"""
    warmup_timeout: builtins.int
    """After how much seconds the warmup will cancel itself"""
    @property
    def batch_job_deployment_size(self) -> global___BatchJobDeploymentSize:
        """The warmup size"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        warmup_timeout: builtins.int = ...,
        batch_job_deployment_size: global___BatchJobDeploymentSize | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_job_deployment_size", b"batch_job_deployment_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_deployment_size", b"batch_job_deployment_size", "branch_id", b"branch_id", "build_id", b"build_id", "model_id", b"model_id", "warmup_timeout", b"warmup_timeout"]) -> None: ...

global___StartWarmupJobRequest = StartWarmupJobRequest

class StartWarmupJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the warmup started successfully"""
    failure_message: builtins.str
    """Failure message in case the warmup start failed"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___StartWarmupJobResponse = StartWarmupJobResponse

class CancelWarmupJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID to cancel the warmup on"""
    branch_id: builtins.str
    """The branch ID for the model"""
    build_id: builtins.str
    """The build ID to cancel the warmup on"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "model_id", b"model_id"]) -> None: ...

global___CancelWarmupJobRequest = CancelWarmupJobRequest

class CancelWarmupJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the warmup cancelled successfully"""
    failure_message: builtins.str
    """Failure message in case the warmup cancel failed"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___CancelWarmupJobResponse = CancelWarmupJobResponse

class StartBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    SOURCE_BUCKET_FIELD_NUMBER: builtins.int
    DESTINATION_BUCKET_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_FIELD_NUMBER: builtins.int
    BATCH_JOB_DEPLOYMENT_SIZE_FIELD_NUMBER: builtins.int
    JOB_TIMEOUT_FIELD_NUMBER: builtins.int
    TASK_TIMEOUT_FIELD_NUMBER: builtins.int
    INPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SECRET_FIELD_NUMBER: builtins.int
    ADVANCED_DEPLOYMENT_OPTIONS_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    BATCH_JOB_REQUEST_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID to start the job on"""
    branch_id: builtins.str
    """The branch ID of the model"""
    build_id: builtins.str
    """Specific build ID the invocation will be executed upon. If empty - deployed build ID will be the default"""
    source_bucket: builtins.str
    """The source bucket from which the files will be read"""
    destination_bucket: builtins.str
    """The destination bucket to which the files will be written"""
    source_folder: builtins.str
    """The source folder from which the files will be read on the source bucket"""
    destination_folder: builtins.str
    """The destination folder to which the files will be written on the destination bucket"""
    @property
    def batch_job_deployment_size(self) -> global___BatchJobDeploymentSize:
        """The batch job size"""
    job_timeout: builtins.int
    """The total batch job timeout in seconds"""
    task_timeout: builtins.int
    """The single task timeout in seconds"""
    input_file_type: global___InputFileType.ValueType
    """The file type for the input files"""
    output_file_type: global___OutputFileType.ValueType
    """The file type for the output files"""
    token_secret: builtins.str
    """The access token's secret name in secret service"""
    secret_secret: builtins.str
    """The access secret's secret name in secret service"""
    @property
    def advanced_deployment_options(self) -> global___AdvancedDeploymentOptions:
        """Advanced deployment options"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchJobParameter]:
        """User provided parameters which will be passed to the batch execution job as environment variables"""
    @property
    def batch_job_request(self) -> global___BatchJobRequest:
        """The request message reorganized
        We will migrate to this massage.
        """
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        source_bucket: builtins.str = ...,
        destination_bucket: builtins.str = ...,
        source_folder: builtins.str = ...,
        destination_folder: builtins.str = ...,
        batch_job_deployment_size: global___BatchJobDeploymentSize | None = ...,
        job_timeout: builtins.int = ...,
        task_timeout: builtins.int = ...,
        input_file_type: global___InputFileType.ValueType = ...,
        output_file_type: global___OutputFileType.ValueType = ...,
        token_secret: builtins.str = ...,
        secret_secret: builtins.str = ...,
        advanced_deployment_options: global___AdvancedDeploymentOptions | None = ...,
        parameters: collections.abc.Iterable[global___BatchJobParameter] | None = ...,
        batch_job_request: global___BatchJobRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "batch_job_deployment_size", b"batch_job_deployment_size", "batch_job_request", b"batch_job_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "batch_job_deployment_size", b"batch_job_deployment_size", "batch_job_request", b"batch_job_request", "branch_id", b"branch_id", "build_id", b"build_id", "destination_bucket", b"destination_bucket", "destination_folder", b"destination_folder", "input_file_type", b"input_file_type", "job_timeout", b"job_timeout", "model_id", b"model_id", "output_file_type", b"output_file_type", "parameters", b"parameters", "secret_secret", b"secret_secret", "source_bucket", b"source_bucket", "source_folder", b"source_folder", "task_timeout", b"task_timeout", "token_secret", b"token_secret"]) -> None: ...

global___StartBatchJobRequest = StartBatchJobRequest

class BatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_DETAILS_FIELD_NUMBER: builtins.int
    DATA_DETAILS_FIELD_NUMBER: builtins.int
    EXECUTION_DETAILS_FIELD_NUMBER: builtins.int
    @property
    def model_details(self) -> global___BatchJobModelDetails:
        """Data about the model to do batch prediction on"""
    @property
    def data_details(self) -> global___BatchJobDataDetails:
        """The params for the data that the prediction executed on"""
    @property
    def execution_details(self) -> global___BatchJobExecutionDetails:
        """How to execute the job"""
    def __init__(
        self,
        *,
        model_details: global___BatchJobModelDetails | None = ...,
        data_details: global___BatchJobDataDetails | None = ...,
        execution_details: global___BatchJobExecutionDetails | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_details", b"data_details", "execution_details", b"execution_details", "model_details", b"model_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data_details", b"data_details", "execution_details", b"execution_details", "model_details", b"model_details"]) -> None: ...

global___BatchJobRequest = BatchJobRequest

class BatchJobModelDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID to start the job on"""
    build_id: builtins.str
    """Specific build ID the invocation will be executed upon. If empty - deployed build ID will be the default"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "model_id", b"model_id"]) -> None: ...

global___BatchJobModelDetails = BatchJobModelDetails

class BatchJobDataDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_PATH_FIELD_NUMBER: builtins.int
    DESTINATION_PATH_FIELD_NUMBER: builtins.int
    TOKEN_SECRET_FIELD_NUMBER: builtins.int
    SECRET_SECRET_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_JSON_KEY_SECRET_FIELD_NUMBER: builtins.int
    @property
    def source_path(self) -> global___BatchJobSourcePath:
        """The source data details"""
    @property
    def destination_path(self) -> global___BatchJobDestinationPath:
        """The destination data details"""
    token_secret: builtins.str
    """The access token's secret name in secret service"""
    secret_secret: builtins.str
    """The access secret's secret name in secret service"""
    service_account_json_key_secret: builtins.str
    """The service account json key secret name"""
    def __init__(
        self,
        *,
        source_path: global___BatchJobSourcePath | None = ...,
        destination_path: global___BatchJobDestinationPath | None = ...,
        token_secret: builtins.str = ...,
        secret_secret: builtins.str = ...,
        service_account_json_key_secret: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_path", b"destination_path", "source_path", b"source_path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_path", b"destination_path", "secret_secret", b"secret_secret", "service_account_json_key_secret", b"service_account_json_key_secret", "source_path", b"source_path", "token_secret", b"token_secret"]) -> None: ...

global___BatchJobDataDetails = BatchJobDataDetails

class BatchJobSourcePath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_BUCKET_FIELD_NUMBER: builtins.int
    SOURCE_FOLDER_FIELD_NUMBER: builtins.int
    INPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    source_bucket: builtins.str
    """The source bucket from which the files will be read"""
    source_folder: builtins.str
    """The source folder from which the files will be read on the source bucket"""
    input_file_type: global___InputFileType.ValueType
    """The file type for the input files"""
    def __init__(
        self,
        *,
        source_bucket: builtins.str = ...,
        source_folder: builtins.str = ...,
        input_file_type: global___InputFileType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["input_file_type", b"input_file_type", "source_bucket", b"source_bucket", "source_folder", b"source_folder"]) -> None: ...

global___BatchJobSourcePath = BatchJobSourcePath

class BatchJobDestinationPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_BUCKET_FIELD_NUMBER: builtins.int
    DESTINATION_FOLDER_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    destination_bucket: builtins.str
    """The destination bucket to which the files will be written"""
    destination_folder: builtins.str
    """The destination folder to which the files will be written on the destination bucket"""
    output_file_type: global___OutputFileType.ValueType
    """The file type for the output files"""
    def __init__(
        self,
        *,
        destination_bucket: builtins.str = ...,
        destination_folder: builtins.str = ...,
        output_file_type: global___OutputFileType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_bucket", b"destination_bucket", "destination_folder", b"destination_folder", "output_file_type", b"output_file_type"]) -> None: ...

global___BatchJobDestinationPath = BatchJobDestinationPath

class BatchJobExecutionDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_TIMEOUT_FIELD_NUMBER: builtins.int
    TASK_TIMEOUT_FIELD_NUMBER: builtins.int
    BATCH_JOB_DEPLOYMENT_SIZE_FIELD_NUMBER: builtins.int
    ADVANCED_DEPLOYMENT_OPTIONS_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    job_timeout: builtins.int
    """The total batch job timeout in seconds"""
    task_timeout: builtins.int
    """The single task timeout in seconds"""
    @property
    def batch_job_deployment_size(self) -> global___BatchJobDeploymentSize:
        """The batch job size"""
    @property
    def advanced_deployment_options(self) -> global___AdvancedDeploymentOptions:
        """Advanced deployment options"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchJobParameter]:
        """User provided parameters which will be passed to the batch execution job as environment variables"""
    def __init__(
        self,
        *,
        job_timeout: builtins.int = ...,
        task_timeout: builtins.int = ...,
        batch_job_deployment_size: global___BatchJobDeploymentSize | None = ...,
        advanced_deployment_options: global___AdvancedDeploymentOptions | None = ...,
        parameters: collections.abc.Iterable[global___BatchJobParameter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "batch_job_deployment_size", b"batch_job_deployment_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "batch_job_deployment_size", b"batch_job_deployment_size", "job_timeout", b"job_timeout", "parameters", b"parameters", "task_timeout", b"task_timeout"]) -> None: ...

global___BatchJobExecutionDetails = BatchJobExecutionDetails

class BatchJobParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

global___BatchJobParameter = BatchJobParameter

class StartBatchJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_ID_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    batch_id: builtins.str
    """The batch job id created"""
    success: builtins.bool
    """Whether the batch job creation succeeded"""
    failure_message: builtins.str
    """The failure message in case the batch job creation failed"""
    def __init__(
        self,
        *,
        batch_id: builtins.str = ...,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_id", b"batch_id", "failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___StartBatchJobResponse = StartBatchJobResponse

class CancelBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_ID_FIELD_NUMBER: builtins.int
    batch_id: builtins.str
    """The batch job id to cancel"""
    def __init__(
        self,
        *,
        batch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_id", b"batch_id"]) -> None: ...

global___CancelBatchJobRequest = CancelBatchJobRequest

class CancelBatchJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the batch job cancel succeeded"""
    failure_message: builtins.str
    """The failure message in case the batch job cancel failed"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___CancelBatchJobResponse = CancelBatchJobResponse

class GetBatchJobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_ID_FIELD_NUMBER: builtins.int
    batch_id: builtins.str
    """The batch job id to get the status for"""
    def __init__(
        self,
        *,
        batch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_id", b"batch_id"]) -> None: ...

global___GetBatchJobStatusRequest = GetBatchJobStatusRequest

class GetBatchJobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_STATUS_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    FINISHED_FILES_FIELD_NUMBER: builtins.int
    TOTAL_FILES_FIELD_NUMBER: builtins.int
    job_status: global___BatchJobStatusMessage.ValueType
    """The status of the batch job"""
    success: builtins.bool
    """Whether the batch job status request succeeded"""
    failure_message: builtins.str
    """The failure message in case the batch job status request failed"""
    finished_files: builtins.int
    """The finished files/tasks in the job"""
    total_files: builtins.int
    """The total files/tasks in the job"""
    def __init__(
        self,
        *,
        job_status: global___BatchJobStatusMessage.ValueType = ...,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
        finished_files: builtins.int = ...,
        total_files: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "finished_files", b"finished_files", "job_status", b"job_status", "success", b"success", "total_files", b"total_files"]) -> None: ...

global___GetBatchJobStatusResponse = GetBatchJobStatusResponse

class GetBatchJobReportRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_ID_FIELD_NUMBER: builtins.int
    batch_id: builtins.str
    """The batch job id to get the report for"""
    def __init__(
        self,
        *,
        batch_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_id", b"batch_id"]) -> None: ...

global___GetBatchJobReportRequest = GetBatchJobReportRequest

class GetBatchJobReportResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESSFUL_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    REPORT_MESSAGES_FIELD_NUMBER: builtins.int
    successful: builtins.bool
    """Whether the batch job report request succeeded"""
    failure_message: builtins.str
    """The failure message in case the batch job report request failed"""
    @property
    def report_messages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The batch job report"""
    def __init__(
        self,
        *,
        successful: builtins.bool = ...,
        failure_message: builtins.str = ...,
        report_messages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "report_messages", b"report_messages", "successful", b"successful"]) -> None: ...

global___GetBatchJobReportResponse = GetBatchJobReportResponse

class UpdateBatchTasksStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_TASK_EVENTS_FIELD_NUMBER: builtins.int
    @property
    def batch_task_events(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.batch_job.v1.batch_job_events_pb2.BatchTaskEventMessage]:
        """Update for multiple batch tasks"""
    def __init__(
        self,
        *,
        batch_task_events: collections.abc.Iterable[qwak.batch_job.v1.batch_job_events_pb2.BatchTaskEventMessage] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_task_events", b"batch_task_events"]) -> None: ...

global___UpdateBatchTasksStatusRequest = UpdateBatchTasksStatusRequest

class UpdateBatchTaskStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """Whether the update to batch tasks was successful"""
    failure_message: builtins.str
    """Failure message in case the update failed"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___UpdateBatchTaskStatusResponse = UpdateBatchTaskStatusResponse

class AdvancedDeploymentOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUSTOM_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_KEY_SECRET_NAME_FIELD_NUMBER: builtins.int
    custom_iam_role_arn: builtins.str
    """Custom IAM Role ARN"""
    purchase_option: builtins.str
    """Whether it is spot/ondemand (default - spot)"""
    service_account_key_secret_name: builtins.str
    """Service account key secret name for gcp"""
    def __init__(
        self,
        *,
        custom_iam_role_arn: builtins.str = ...,
        purchase_option: builtins.str = ...,
        service_account_key_secret_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_iam_role_arn", b"custom_iam_role_arn", "purchase_option", b"purchase_option", "service_account_key_secret_name", b"service_account_key_secret_name"]) -> None: ...

global___AdvancedDeploymentOptions = AdvancedDeploymentOptions

class BatchJobDeploymentSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _MemoryUnit:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BatchJobDeploymentSize._MemoryUnit.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: BatchJobDeploymentSize._MemoryUnit.ValueType  # 0
        MIB: BatchJobDeploymentSize._MemoryUnit.ValueType  # 1
        GIB: BatchJobDeploymentSize._MemoryUnit.ValueType  # 2

    class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...
    UNKNOWN: BatchJobDeploymentSize.MemoryUnit.ValueType  # 0
    MIB: BatchJobDeploymentSize.MemoryUnit.ValueType  # 1
    GIB: BatchJobDeploymentSize.MemoryUnit.ValueType  # 2

    NUMBER_OF_PODS_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    CLIENT_POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    number_of_pods: builtins.int
    """Number of pods to deploy"""
    cpu: builtins.float
    """Cpu"""
    memory_amount: builtins.int
    """Amount of memory"""
    memory_units: global___BatchJobDeploymentSize.MemoryUnit.ValueType
    """Units type of memory"""
    @property
    def gpu_resources(self) -> qwak.user_application.common.v0.resources_pb2.GpuResources:
        """Optional GPU resources for batch"""
    @property
    def client_pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources:
        """Client Compute Resources"""
    def __init__(
        self,
        *,
        number_of_pods: builtins.int = ...,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___BatchJobDeploymentSize.MemoryUnit.ValueType = ...,
        gpu_resources: qwak.user_application.common.v0.resources_pb2.GpuResources | None = ...,
        client_pod_compute_resources: qwak.user_application.common.v0.resources_pb2.ClientPodComputeResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "gpu_resources", b"gpu_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_pod_compute_resources", b"client_pod_compute_resources", "cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "number_of_pods", b"number_of_pods"]) -> None: ...

global___BatchJobDeploymentSize = BatchJobDeploymentSize

class BatchJobExecutionSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_OF_PODS_FIELD_NUMBER: builtins.int
    POD_COMPUTE_RESOURCES_FIELD_NUMBER: builtins.int
    TEMPLATE_ID_FIELD_NUMBER: builtins.int
    number_of_pods: builtins.int
    """Number of pods in execution"""
    @property
    def pod_compute_resources(self) -> qwak.user_application.common.v0.resources_pb2.PodComputeResources:
        """Resources Of Execution"""
    template_id: builtins.str
    """Template id used"""
    def __init__(
        self,
        *,
        number_of_pods: builtins.int = ...,
        pod_compute_resources: qwak.user_application.common.v0.resources_pb2.PodComputeResources | None = ...,
        template_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pod_compute_resources", b"pod_compute_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["number_of_pods", b"number_of_pods", "pod_compute_resources", b"pod_compute_resources", "template_id", b"template_id"]) -> None: ...

global___BatchJobExecutionSize = BatchJobExecutionSize

class ListBatchJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model ID to get the list of batch jobs for"""
    branch_id: builtins.str
    """The branch ID for the model"""
    build_id: builtins.str
    """The build ID to get the list of batch jobs for"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "model_id", b"model_id"]) -> None: ...

global___ListBatchJobsRequest = ListBatchJobsRequest

class ListBatchJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_JOBS_FIELD_NUMBER: builtins.int
    @property
    def batch_jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BatchJobDetails]:
        """The details for each batch job"""
    def __init__(
        self,
        *,
        batch_jobs: collections.abc.Iterable[global___BatchJobDetails] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_jobs", b"batch_jobs"]) -> None: ...

global___ListBatchJobsResponse = ListBatchJobsResponse

class BatchJobDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    JOB_STATUS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    JOB_SIZE_FIELD_NUMBER: builtins.int
    BATCH_JOB_EXECUTION_SIZE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The build id used in the batch job"""
    job_id: builtins.str
    """The batch job id"""
    job_status: global___BatchJobStatusMessage.ValueType
    """The batch job status"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The start time for of the batch job"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The end time for of the batch job"""
    failure_message: builtins.str
    """The failure message of the batch job in case that failed"""
    @property
    def job_size(self) -> global___BatchJobDeploymentSize:
        """The batch job resources size"""
    @property
    def batch_job_execution_size(self) -> global___BatchJobExecutionSize:
        """The batch job resources size"""
    environment_id: builtins.str
    """Environment id"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        job_id: builtins.str = ...,
        job_status: global___BatchJobStatusMessage.ValueType = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        failure_message: builtins.str = ...,
        job_size: global___BatchJobDeploymentSize | None = ...,
        batch_job_execution_size: global___BatchJobExecutionSize | None = ...,
        environment_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_job_execution_size", b"batch_job_execution_size", "end_time", b"end_time", "job_size", b"job_size", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job_execution_size", b"batch_job_execution_size", "build_id", b"build_id", "end_time", b"end_time", "environment_id", b"environment_id", "failure_message", b"failure_message", "job_id", b"job_id", "job_size", b"job_size", "job_status", b"job_status", "start_time", b"start_time"]) -> None: ...

global___BatchJobDetails = BatchJobDetails

class GetBatchJobDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The batch job ID"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___GetBatchJobDetailsRequest = GetBatchJobDetailsRequest

class GetBatchJobDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_JOB_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def batch_job(self) -> global___BatchJobMessage:
        """The batch job details"""
    success: builtins.bool
    """Whether the request was successful"""
    failure_message: builtins.str
    """Failure message in case the request failed"""
    def __init__(
        self,
        *,
        batch_job: global___BatchJobMessage | None = ...,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_job", b"batch_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_job", b"batch_job", "failure_message", b"failure_message", "success", b"success"]) -> None: ...

global___GetBatchJobDetailsResponse = GetBatchJobDetailsResponse

class BatchJobMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    JOB_STATUS_FIELD_NUMBER: builtins.int
    TOTAL_RECORDS_FIELD_NUMBER: builtins.int
    JOB_SIZE_FIELD_NUMBER: builtins.int
    REPORT_MESSAGES_FIELD_NUMBER: builtins.int
    EXECUTION_FILE_DETAILS_FIELD_NUMBER: builtins.int
    TASK_EXECUTIONS_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The batch job id"""
    model_id: builtins.str
    """The model ID for the batch job"""
    branch_id: builtins.str
    """The branch id of the model"""
    build_id: builtins.str
    """The build ID used in the batch job"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The start time for of the batch job"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The end time for of the batch job"""
    job_status: global___BatchJobStatusMessage.ValueType
    """The batch job status"""
    total_records: builtins.int
    """The total records that were processed in the job"""
    @property
    def job_size(self) -> global___BatchJobDeploymentSize:
        """The batch job size"""
    @property
    def report_messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ExecutionReportLine]:
        """The report for the batch job"""
    @property
    def execution_file_details(self) -> global___ExecutionFileDetails:
        """Details on the files processed in the batch job"""
    @property
    def task_executions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TaskExecutionDetails]:
        """Details for each of the task execution"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        model_id: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        job_status: global___BatchJobStatusMessage.ValueType = ...,
        total_records: builtins.int = ...,
        job_size: global___BatchJobDeploymentSize | None = ...,
        report_messages: collections.abc.Iterable[global___ExecutionReportLine] | None = ...,
        execution_file_details: global___ExecutionFileDetails | None = ...,
        task_executions: collections.abc.Iterable[global___TaskExecutionDetails] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "execution_file_details", b"execution_file_details", "job_size", b"job_size", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "end_time", b"end_time", "execution_file_details", b"execution_file_details", "job_id", b"job_id", "job_size", b"job_size", "job_status", b"job_status", "model_id", b"model_id", "report_messages", b"report_messages", "start_time", b"start_time", "task_executions", b"task_executions", "total_records", b"total_records"]) -> None: ...

global___BatchJobMessage = BatchJobMessage

class ExecutionReportLine(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The report time"""
    line: builtins.str
    """The report details"""
    def __init__(
        self,
        *,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        line: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["line", b"line", "time", b"time"]) -> None: ...

global___ExecutionReportLine = ExecutionReportLine

class ExecutionFileDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SOURCE_BUCKET_FIELD_NUMBER: builtins.int
    DESTINATION_BUCKET_FIELD_NUMBER: builtins.int
    SOURCE_PATH_FIELD_NUMBER: builtins.int
    DESTINATION_PATH_FIELD_NUMBER: builtins.int
    INPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    OUTPUT_FILE_TYPE_FIELD_NUMBER: builtins.int
    FINISHED_FILES_FIELD_NUMBER: builtins.int
    TOTAL_FILES_FIELD_NUMBER: builtins.int
    source_bucket: builtins.str
    """The source bucket from which the files are read"""
    destination_bucket: builtins.str
    """The destination bucket to which the files are written"""
    source_path: builtins.str
    """The source path from which the files are read on the source bucket"""
    destination_path: builtins.str
    """The destination path to which the files are written on the destination bucket"""
    input_file_type: global___InputFileType.ValueType
    """The file type for the input files"""
    output_file_type: global___OutputFileType.ValueType
    """The file type for the output files"""
    finished_files: builtins.int
    """The finished files/tasks in the job"""
    total_files: builtins.int
    """The total files/tasks in the job"""
    def __init__(
        self,
        *,
        source_bucket: builtins.str = ...,
        destination_bucket: builtins.str = ...,
        source_path: builtins.str = ...,
        destination_path: builtins.str = ...,
        input_file_type: global___InputFileType.ValueType = ...,
        output_file_type: global___OutputFileType.ValueType = ...,
        finished_files: builtins.int = ...,
        total_files: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_bucket", b"destination_bucket", "destination_path", b"destination_path", "finished_files", b"finished_files", "input_file_type", b"input_file_type", "output_file_type", b"output_file_type", "source_bucket", b"source_bucket", "source_path", b"source_path", "total_files", b"total_files"]) -> None: ...

global___ExecutionFileDetails = ExecutionFileDetails

class TaskExecutionDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    NUM_OF_RECORDS_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """The task id"""
    status: global___BatchTaskStatusMessage.ValueType
    """The task status"""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The task's start time"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The task's end time"""
    num_of_records: builtins.int
    """The task's number of records processed"""
    filename: builtins.str
    """The task's filename"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        status: global___BatchTaskStatusMessage.ValueType = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        num_of_records: builtins.int = ...,
        filename: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "filename", b"filename", "num_of_records", b"num_of_records", "start_time", b"start_time", "status", b"status", "task_id", b"task_id"]) -> None: ...

global___TaskExecutionDetails = TaskExecutionDetails

class GetBatchJobPreSignedUploadUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    NUMBER_OF_FILES_FIELD_NUMBER: builtins.int
    FILE_TYPE_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id to receive a signed url for"""
    number_of_files: builtins.int
    """The number of files to upload"""
    file_type: builtins.str
    """The file type of the files"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        number_of_files: builtins.int = ...,
        file_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_type", b"file_type", "model_id", b"model_id", "number_of_files", b"number_of_files"]) -> None: ...

global___GetBatchJobPreSignedUploadUrlRequest = GetBatchJobPreSignedUploadUrlRequest

class GetBatchJobPreSignedUploadUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_PATH_FIELD_NUMBER: builtins.int
    OUTPUT_PATH_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    URLS_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    input_path: builtins.str
    """The generated files path to store the files on"""
    output_path: builtins.str
    """The designated output path"""
    bucket: builtins.str
    """The bucket name to use"""
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The pre-signed urls"""
    success: builtins.bool
    """Whether the request succeeded"""
    failure_message: builtins.str
    """Failure message in case the request failed"""
    def __init__(
        self,
        *,
        input_path: builtins.str = ...,
        output_path: builtins.str = ...,
        bucket: builtins.str = ...,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "failure_message", b"failure_message", "input_path", b"input_path", "output_path", b"output_path", "success", b"success", "urls", b"urls"]) -> None: ...

global___GetBatchJobPreSignedUploadUrlResponse = GetBatchJobPreSignedUploadUrlResponse

class GetBatchJobPreSignedDownloadUrlRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The job id to get the download urls for"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___GetBatchJobPreSignedDownloadUrlRequest = GetBatchJobPreSignedDownloadUrlRequest

class GetBatchJobPreSignedDownloadUrlResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URLS_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_MESSAGE_FIELD_NUMBER: builtins.int
    @property
    def urls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The pre-signed urls"""
    success: builtins.bool
    """Whether the request succeeded"""
    failure_message: builtins.str
    """Failure message in case the request failed"""
    def __init__(
        self,
        *,
        urls: collections.abc.Iterable[builtins.str] | None = ...,
        success: builtins.bool = ...,
        failure_message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_message", b"failure_message", "success", b"success", "urls", b"urls"]) -> None: ...

global___GetBatchJobPreSignedDownloadUrlResponse = GetBatchJobPreSignedDownloadUrlResponse

class GetBatchJobUploadDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    """The model id to receive a signed url for"""
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id"]) -> None: ...

global___GetBatchJobUploadDetailsRequest = GetBatchJobUploadDetailsRequest

class GetBatchJobUploadDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_PATH_FIELD_NUMBER: builtins.int
    OUTPUT_PATH_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    input_path: builtins.str
    """The generated files path to store the files on"""
    output_path: builtins.str
    """The designated output path"""
    bucket: builtins.str
    """The bucket name to use"""
    @property
    def credentials(self) -> qwak.administration.authenticated_user.v1.credentials_pb2.AwsTemporaryCredentials:
        """Temp credentials for uploading files"""
    def __init__(
        self,
        *,
        input_path: builtins.str = ...,
        output_path: builtins.str = ...,
        bucket: builtins.str = ...,
        credentials: qwak.administration.authenticated_user.v1.credentials_pb2.AwsTemporaryCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "credentials", b"credentials", "input_path", b"input_path", "output_path", b"output_path"]) -> None: ...

global___GetBatchJobUploadDetailsResponse = GetBatchJobUploadDetailsResponse

class GetBatchJobDownloadDetailsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The job id to get the download keys for"""
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["job_id", b"job_id"]) -> None: ...

global___GetBatchJobDownloadDetailsRequest = GetBatchJobDownloadDetailsRequest

class GetBatchJobDownloadDetailsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    KEYS_FIELD_NUMBER: builtins.int
    CREDENTIALS_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    """The bucket name to use"""
    @property
    def keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The files keys"""
    @property
    def credentials(self) -> qwak.administration.authenticated_user.v1.credentials_pb2.AwsTemporaryCredentials:
        """Temp credentials for download files"""
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        keys: collections.abc.Iterable[builtins.str] | None = ...,
        credentials: qwak.administration.authenticated_user.v1.credentials_pb2.AwsTemporaryCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["credentials", b"credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "credentials", b"credentials", "keys", b"keys"]) -> None: ...

global___GetBatchJobDownloadDetailsResponse = GetBatchJobDownloadDetailsResponse

class UpdateDefaultParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    DEFAULT_DEPLOYMENT_SIZE_FIELD_NUMBER: builtins.int
    ADVANCED_DEPLOYMENT_OPTIONS_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    build_id: builtins.str
    @property
    def default_deployment_size(self) -> global___BatchJobDeploymentSize: ...
    @property
    def advanced_deployment_options(self) -> global___AdvancedDeploymentOptions: ...
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
        build_id: builtins.str = ...,
        default_deployment_size: global___BatchJobDeploymentSize | None = ...,
        advanced_deployment_options: global___AdvancedDeploymentOptions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "default_deployment_size", b"default_deployment_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_deployment_options", b"advanced_deployment_options", "build_id", b"build_id", "default_deployment_size", b"default_deployment_size", "model_id", b"model_id"]) -> None: ...

global___UpdateDefaultParamsRequest = UpdateDefaultParamsRequest

class UpdateDefaultParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateDefaultParamsResponse = UpdateDefaultParamsResponse

class DeleteDefaultParamsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ID_FIELD_NUMBER: builtins.int
    model_id: builtins.str
    def __init__(
        self,
        *,
        model_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_id", b"model_id"]) -> None: ...

global___DeleteDefaultParamsRequest = DeleteDefaultParamsRequest

class DeleteDefaultParamsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteDefaultParamsResponse = DeleteDefaultParamsResponse

class UpdateTaskIngestedRecordsAmountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_ID_FIELD_NUMBER: builtins.int
    INGESTED_RECORDS_FIELD_NUMBER: builtins.int
    task_id: builtins.str
    """The task id"""
    ingested_records: builtins.int
    """The number of ingested records"""
    def __init__(
        self,
        *,
        task_id: builtins.str = ...,
        ingested_records: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingested_records", b"ingested_records", "task_id", b"task_id"]) -> None: ...

global___UpdateTaskIngestedRecordsAmountRequest = UpdateTaskIngestedRecordsAmountRequest

class UpdateTaskIngestedRecordsAmountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateTaskIngestedRecordsAmountResponse = UpdateTaskIngestedRecordsAmountResponse
